--[[----------------------------------------------------------------------]]--
--[[--LostTreasures.lua													--]]--
--[[--See README.html for more info										--]]--
--[[----------------------------------------------------------------------]]--

LostTreasures = LibStub("AceAddon-3.0"):NewAddon("LostTreasures", "AceEvent-3.0", "AceConsole-3.0")
LibMapData = LibStub("LibMapData-1.0")

--[[----------------------------------------------------------------------]]--
--[[--Event Handler														--]]--
--[[----------------------------------------------------------------------]]--
function LostTreasures:PLAYER_LOGIN(event)
	LostTreasures:UnregisterEvent(event)
	LostTreasures:DoWaypoints({removeAll = false})
end
LostTreasures:RegisterEvent("PLAYER_LOGIN")

--[[----------------------------------------------------------------------]]--
--[[--Other Functions													--]]--
--[[----------------------------------------------------------------------]]--
function printd(msg)
	if ( _LT.sv.DEBUG ) then
		print("LT: "..msg)
	end
end

function LostTreasures:RefreshConfig()
	AceConfigRegistry:NotifyChange(_LT.NAME)
end

function LostTreasures:ConfirmDialog(opts)
	if ( opts.btn1 == nil ) then opts.btn1 = "Accept" end
	if ( opts.btn2 == nil ) then opts.btn2 = "Cancel" end
	if ( opts.func2 == nil ) then
		opts.func2 = function() return end
	end
	StaticPopupDialogs["CONFIRM_DIALOG"] = {
		text = opts.text, 
		button1 = opts.btn1, 
		button2 = opts.btn2, 
		OnAccept = opts.func1, 
		OnCancel = opts.func2, 
		timeout = 30, 
		whileDead = 1, 
		hideOnEscape = 1, 
	}
	StaticPopup_Show("CONFIRM_DIALOG")
end

--[[----------------------------------------------------------------------]]--
--[[--Core Functions													--]]--
--[[----------------------------------------------------------------------]]--
function LostTreasures:OnInitialize()

	self.db = LibStub("AceDB-3.0"):New("LostTreasuresDB", _LT.defaults)
	self.db.RegisterCallback(self, "OnProfileChanged", "RefreshConfig")
	self.db.RegisterCallback(self, "OnProfileCopied", "RefreshConfig")
	self.db.RegisterCallback(self, "OnProfileReset", "RefreshConfig")
	_LT.sv = LostTreasures.db.char
	
	if ( _LT.sv.VERSION ~= _LT.VERSION ) then
		_LT.sv.VERSION = _LT.VERSION
		print("LostTreasures successfully updated from ".._LT.sv.VERSION.." to ".._LT.VERSION.."!")
	end
	
	self:RegisterChatCommand("lt", "HandleCommand")
	self:RegisterChatCommand("losttreasures", "HandleCommand")
end

function LostTreasures:HandleCommand(args)
	local cmd, input = self:GetArgs(args, 2)
	if ( cmd == "reset" ) then
		LostTreasures:DoWaypoints()
		printd("Waypoints reset.")
	elseif ( cmd == "removeall" ) then
		LostTreasures:DoWaypoints({addAll = false})
		printd("Removed all waypoints.")
	elseif ( cmd == "remove" ) then
		LostTreasures:DoWaypoints({removeAll = false, addAll = false, removePoint = input})
		printd("Removed waypoint. QuestId: "..input)
	elseif ( cmd == "add" ) then
		LostTreasures:DoWaypoints({removeAll = false, addAll = false, addPoint = input})
		printd("Added waypoint. QuestId: "..input)
	else
		InterfaceOptionsFrame_OpenToCategory(_LT.NAME)
	end
end

_LT = {
	NAME = "LostTreasures", 
	VERSION = GetAddOnMetadata("LostTreasures", "Version"), 
	
	defaults = {
		char = {
			VERSION = 0, 
			
			-- START SETTINGS --
			ENABLED = true, 
			DEBUG = false, 
			BLOCK_MINING_PICK = false, 
			USE_MINIMAP = true, 
			USE_WORLDMAP = true, 
			SHOW_ALL_WAYPOINTS = false, 
			USE_SESSIONS = true, 
			SHOW_WAYPOINT_TYPE = 1, -- 1 = all, 2 = greys, 3 = rares
			USE_ARROW = true, 
			TREASURE_FIRST = true, 
			SHOW_DETAILED_INFO = true, 
			CAVES_FIRST = true, 
			CLEARDISTANCE = 3, 
			-- END SETTINGS --
			
			BLOCKED_WAYPOINTS = {}, -- Allows us to save which points have been checked between sessions.
		}, 
	}, 
}